pub struct CsvLoader { /* private fields */ }Expand description
Loads documents from CSV data. Each row becomes a Document.
The content_column specifies which column to use as document content.
If not set, all columns are concatenated.
An id_column can optionally specify the column for document IDs.
Implementations