FileLoader

Struct FileLoader 

pub struct FileLoader { /* private fields */ }
Loads content from a file on disk.

Reads the file contents via tokio::fs::read_to_string and returns a single Document with the file path as id and the file contents as content. The source metadata key is set to the file path.

Implementations

Source

impl FileLoader

pub fn new(path: impl Into<PathBuf>) -> Self