pub struct JsonLoader { /* private fields */ }Expand description
Loads documents from a JSON string.
- If the JSON is an array of objects, each object becomes a Document.
The
content_keyfield is used to extract the document content (default: “content”). Theid_keyfield is used to extract the document id (default: “id”). - If the JSON is a single object, it becomes one Document.
Implementations
Sourceimpl JsonLoader
impl JsonLoader