pub struct FileLoader { /* private fields */ }Expand description
Loads content from a file on disk.
Reads the file contents via tokio::fs::read_to_string and returns a single
Document with the file path as id and the file contents as content.
The source metadata key is set to the file path.
Implementations